@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2010 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -73,7 +73,7 @@ computed_index(GkrellmChart *cp, gint i)
 	}
 
 GList *
-gkrellm_get_chart_list()
+gkrellm_get_chart_list(void)
 	{
 	return chart_list;
 	}
@@ -114,8 +114,8 @@ gkrellm_clear_chart(GkrellmChart *cp)
 						0, 0,	0, 0,   cp->w, cp->h);
 	gdk_draw_drawable(cp->bg_pixmap, _GK.draw1_GC, cp->bg_src_pixmap,
 						0, 0,	0, 0,   cp->w, cp->h);
-	if (cp->drawing_area->window)
-		gdk_draw_drawable(cp->drawing_area->window, _GK.draw1_GC, cp->pixmap,
+	if (gtk_widget_get_window(cp->drawing_area))
+		gdk_draw_drawable(gtk_widget_get_window(cp->drawing_area), _GK.draw1_GC, cp->pixmap,
 						0, 0,	0, 0,   cp->w, cp->h);
 	}
 
@@ -158,8 +158,8 @@ gkrellm_draw_chart_to_screen(GkrellmChart *cp)
 	{
 	/* Draw the expose pixmap onto the screen.
 	*/
-	if (cp && cp->drawing_area->window)
-		gdk_draw_drawable(cp->drawing_area->window, _GK.draw1_GC, cp->pixmap,
+	if (cp && gtk_widget_get_window(cp->drawing_area))
+		gdk_draw_drawable(gtk_widget_get_window(cp->drawing_area), _GK.draw1_GC, cp->pixmap,
 						0, 0,	0, 0,   cp->w, cp->h);
 	}
 
@@ -267,6 +267,16 @@ gkrellm_set_chartdata_flags(GkrellmChartdata *cd, gint flags)
 		cd->flags = flags;
 	}
 
+static void
+gk_draw_vertical_line(GdkDrawable *drawable, GdkGC *gc, gint x, gint y1, gint y2)
+	{
+	if (y1 == y2)
+		gdk_draw_point(drawable, gc, x, y1);
+	else
+		gdk_draw_line(drawable, gc, x, y1, x, y2);
+	}
+
+
 static gint
 chartdata_ycoord(GkrellmChart *cp, GkrellmChartdata *cd, gint yd)
 	{
@@ -413,7 +423,7 @@ draw_chartdata_impulses(GkrellmChart *cp, GList *cd_list,
 				yI += cd->data[x];
 				y = chartdata_ycoord(cp, cd, yI);
 				if (cd->data[x] > 0)
-					gdk_draw_line(cd->data_bitmap, _GK.bit1_GC, n, y1, n, y);
+					gk_draw_vertical_line(cd->data_bitmap, _GK.bit1_GC, n, y1, y);
 				y1 = y;
 				}
 			else
@@ -423,7 +433,7 @@ draw_chartdata_impulses(GkrellmChart *cp, GList *cd_list,
 				yN += cd->data[x];
 				y = chartdata_ycoord(cp, cd, yN);
 				if (cd->data[x] > 0)
-					gdk_draw_line(cd->data_bitmap, _GK.bit1_GC, n, y0, n, y);
+					gk_draw_vertical_line(cd->data_bitmap, _GK.bit1_GC, n, y0, y);
 				y0 = y;
 				}
 			}
@@ -501,11 +511,7 @@ draw_chartdata_lines(GkrellmChart *cp, GkrellmChartdata *cd, gint i0)
 		cd->y_p_valid = FALSE;	/* Need a store_chartdata to make it valid */
 		if (cd->data[x] > 0 || (cd->inverted ? (y > y0) : (y < y0)))
 			{
-			if (y == y1)
-				gdk_draw_point(cd->data_bitmap, _GK.bit1_GC, cp->x + n, y1);
-			else
-				gdk_draw_line(cd->data_bitmap, _GK.bit1_GC,
-						cp->x + n, y, cp->x + n, y1);
+			gk_draw_vertical_line(cd->data_bitmap, _GK.bit1_GC, cp->x + n, y, y1);
 			}
 		}
 	/* Push the grided pixmap through the data bitmap onto the expose pixmap
@@ -692,7 +698,7 @@ gkrellm_alloc_chartdata(GkrellmChart *cp)
 		cd->w = w;
 		if (cd->data)
 			g_free(cd->data);
-		cd->data = (gint *) g_new0(gint, w);
+		cd->data = (gulong *) g_new0(gulong, w);
 		cd->maxval = 0;
 		cp->position = cp->w - 1;
 		cp->tail = cp->position;
@@ -841,8 +847,14 @@ gkrellm_store_chartdatav(GkrellmChart *cp, gulong total, va_list args)
 			}
 		/* Prime the pump.  Also handle data wrap around or reset to zero.
 		*/
-		if (cd->current < cd->previous || !cp->primed)
+		cd->wrap = 0;
+		if (!cp->primed)
 			cd->previous = cd->current;
+		else if (cd->current < cd->previous)
+			{
+			cd->wrap = (gulong) -1 - cd->previous;
+			cd->previous = 0;
+			}
 		}
 	if (total < cp->previous_total || !cp->primed)
 		cp->previous_total = total;	  /* Wrap around, this store won't scale */
@@ -865,7 +877,7 @@ gkrellm_store_chartdatav(GkrellmChart *cp, gulong total, va_list args)
 		{
 		cd = (GkrellmChartdata *) list->data;
 		cd->discard = cd->data[cp->tail];
-		cd->data[n] = (gint)(cd->current - cd->previous);
+		cd->data[n] = (gulong)(cd->current - cd->previous) + cd->wrap;
 		cd->previous = cd->current;
 
 		/* If using totals, scale the stored data to range between 0 and the
@@ -1452,7 +1464,7 @@ gkrellm_add_chartdata(GkrellmChart *cp, GdkPixmap **src_pixmap,
 	if (!cp || !src_pixmap || !grid_pixmap || !label)
 		return NULL;
 
-	/* To handle theme and vert size changes without loosing data, reuse the
+	/* To handle theme and vert size changes without losing data, reuse the
 	|  GkrellmChartdata structs in the cd_list.
 	*/
 	list = g_list_nth(cp->cd_list, cp->cd_list_index++);
@@ -1468,8 +1480,8 @@ gkrellm_add_chartdata(GkrellmChart *cp, GdkPixmap **src_pixmap,
 	cd->chart = cp;
 	gkrellm_dup_string(&cd->label, label);
 	cd->monotonic = TRUE;
-	cd->data_bitmap = gdk_pixmap_new(top_win->window, cp->w, cp->h, 1);
-	cd->layer.pixmap = gdk_pixmap_new(top_win->window, cp->w, cp->h, -1);
+	cd->data_bitmap = gdk_pixmap_new(gtk_widget_get_window(top_win), cp->w, cp->h, 1);
+	cd->layer.pixmap = gdk_pixmap_new(gtk_widget_get_window(top_win), cp->w, cp->h, -1);
 	cd->layer.src_pixmap = src_pixmap;
 	cd->layer.grid_pixmap = grid_pixmap;
 
@@ -1498,7 +1510,7 @@ gkrellm_render_data_grid_pixmap(GkrellmPiximage *im, GdkPixmap **pixmap,
 		else
 			{
 			gkrellm_free_pixmap(pixmap);
-			*pixmap = gdk_pixmap_new(top_win->window, w, 1, -1);
+			*pixmap = gdk_pixmap_new(gtk_widget_get_window(top_win), w, 1, -1);
 			if (color)
 				gdk_gc_set_foreground(_GK.draw1_GC, color);
 			else
@@ -1523,7 +1535,7 @@ gkrellm_render_data_pixmap(GkrellmPiximage *im, GdkPixmap **pixmap,
 		{
 		if (!gkrellm_scale_piximage_to_pixmap(im, pixmap, NULL, w, h))
 			{
-			*pixmap = gdk_pixmap_new(top_win->window, w, h, -1);
+			*pixmap = gdk_pixmap_new(gtk_widget_get_window(top_win), w, h, -1);
 			if (color)
 				gdk_gc_set_foreground(_GK.draw1_GC, color);
 			else
@@ -1742,22 +1754,11 @@ render_chart_margin_spacers(GkrellmChart *cp)
 		gtk_widget_hide(bs->vbox);
 	}
 
-#if 0
-static gboolean
-cb_chart_map_event(GtkWidget *widget, GdkEvent *event, GkrellmChart *cp)
-    {
-    gdk_window_get_position(cp->drawing_area->window, NULL, &cp->y_mapped);
-	if (_GK.frame_left_chart_overlap > 0 || _GK.frame_right_chart_overlap > 0)
-		_GK.need_frame_packing = TRUE;
-    return FALSE;
-    }
-#endif
-
 static gboolean
 cb_chart_size_allocate(GtkWidget *widget, GtkAllocation *size,
 				GkrellmChart *cp)
     {
-    gdk_window_get_position(cp->drawing_area->window, NULL, &cp->y_mapped);
+    gdk_window_get_position(gtk_widget_get_window(cp->drawing_area), NULL, &cp->y_mapped);
 	if (_GK.frame_left_chart_overlap > 0 || _GK.frame_right_chart_overlap > 0)
 		_GK.need_frame_packing = TRUE;
     return FALSE;
@@ -1870,9 +1871,7 @@ gkrellm_chart_create(GtkWidget *vbox, GkrellmMonitor *mon, GkrellmChart *cp,
 		cp->style_id = style_id;
 		insert_in_chartlist(cp);
 		cp->y_mapped = -1;
-//		g_signal_connect(G_OBJECT (cp->drawing_area), "map_event",
-//					G_CALLBACK(cb_chart_map_event), cp);
-		g_signal_connect(G_OBJECT (cp->drawing_area), "size_allocate",
+		g_signal_connect(G_OBJECT (cp->drawing_area), "size-allocate",
 					G_CALLBACK(cb_chart_size_allocate), cp);
 		}
 	else
@@ -2036,6 +2035,7 @@ cb_chart_grid_resolution(GtkWidget *adjustment, GkrellmChart *cp)
 	gint			res;
 	gfloat			fres;
 
+	_GK.config_modified = TRUE;
 	cf = cp->config;
 	spin = GTK_SPIN_BUTTON(cf->grid_resolution_spin_button);
 	if (cf->map_sequence)
@@ -2094,7 +2094,7 @@ gkrellm_get_chartconfig_grid_resolution(GkrellmChartconfig *cf)
 
 void
 gkrellm_chartconfig_grid_resolution_connect(GkrellmChartconfig *cf,
-			void (*func)(gpointer), gpointer data)
+			void (*func)(GkrellmChartconfig *, gpointer), gpointer data)
 	{
 	if (!cf)
 		return;
@@ -2193,7 +2193,7 @@ gkrellm_get_chartconfig_fixed_grids(GkrellmChartconfig *cf)
 
 void
 gkrellm_chartconfig_fixed_grids_connect(GkrellmChartconfig *cf,
-			void (*func)(gpointer), gpointer data)
+			void (*func)(GkrellmChartconfig*, gpointer), gpointer data)
 	{
 	if (!cf)
 		return;
@@ -2211,7 +2211,7 @@ gkrellm_get_chartconfig_height(GkrellmChartconfig *cf)
 
 void
 gkrellm_chartconfig_height_connect(GkrellmChartconfig *cf,
-			void (*func)(gpointer), gpointer data)
+			void (*func)(GkrellmChartconfig*, gpointer), gpointer data)
 	{
 	if (!cf)
 		return;
@@ -2240,8 +2240,8 @@ gkrellm_set_chart_height(GkrellmChart *cp, gint h)
 		cd = (GkrellmChartdata *) list->data;
 		g_object_unref(G_OBJECT(cd->data_bitmap));
 		g_object_unref(G_OBJECT(cd->layer.pixmap));
-		cd->data_bitmap = gdk_pixmap_new(top_win->window, cp->w, cp->h, 1);
-		cd->layer.pixmap = gdk_pixmap_new(top_win->window, cp->w, cp->h, -1);
+		cd->data_bitmap = gdk_pixmap_new(gtk_widget_get_window(top_win), cp->w, cp->h, 1);
+		cd->layer.pixmap = gdk_pixmap_new(gtk_widget_get_window(top_win), cp->w, cp->h, -1);
 		}
 	cp->bg_sequence_id += 1;
 	render_chart_pixmaps(cp);
@@ -2303,15 +2303,15 @@ set_resolution_menubar_items_sensitivity(GkrellmChartconfig *cf)
 	{
 	GtkWidget	*w;
 
-	if (!cf->auto_resolution_item_factory)
+	if (!cf->auto_resolution_ui_manager)
 		return;
 
-	w = gtk_item_factory_get_widget(cf->auto_resolution_item_factory,
-				_("/Control/Auto mode sticks at peak value"));
-	GTK_CHECK_MENU_ITEM(w)->active = cf->auto_resolution_stick;
+	w = gtk_ui_manager_get_widget(cf->auto_resolution_ui_manager,
+                                      "/menubar/Control/AutoModeStickPeak");
+	gtk_check_menu_item_set_active(GTK_CHECK_MENU_ITEM(w), cf->auto_resolution_stick);
 
-	w = gtk_item_factory_get_widget(cf->auto_resolution_item_factory,
-				_("/Control/Auto mode recalibrate"));
+	w = gtk_ui_manager_get_widget(cf->auto_resolution_ui_manager,
+                                      "/menubar/Control/AutoModeRecalibrate");
 	if (cf->auto_grid_resolution)
 		gtk_widget_set_sensitive(w, TRUE);
 	else
@@ -2353,7 +2353,7 @@ static void
 cb_line_draw_style(GtkWidget *widget, GkrellmChartdata *cd)
 	{
 	_GK.config_modified = TRUE;
-	cd->draw_style = GTK_TOGGLE_BUTTON(widget)->active;
+	cd->draw_style = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 	gkrellm_rescale_chart(cd->chart);
 	}
 
@@ -2364,7 +2364,7 @@ cb_auto_resolution(GtkWidget *widget, GkrellmChart *cp)
 	GkrellmChartconfig	*cf = cp->config;
 
 	_GK.config_modified = TRUE;
-	cf->auto_grid_resolution = GTK_TOGGLE_BUTTON(widget)->active;
+	cf->auto_grid_resolution = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 
 	set_resolution_menubar_items_sensitivity(cf);
 	button = cf->grid_resolution_spin_button;
@@ -2379,7 +2379,7 @@ static void
 cb_inverted_draw_mode(GtkWidget *widget, GkrellmChartdata *cd)
 	{
 	_GK.config_modified = TRUE;
-	cd->inverted = GTK_TOGGLE_BUTTON(widget)->active;
+	cd->inverted = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 	gkrellm_rescale_chart(cd->chart);
 	}
 
@@ -2387,7 +2387,7 @@ static void
 cb_hide(GtkWidget *widget, GkrellmChartdata *cd)
 	{
 	_GK.config_modified = TRUE;
-	cd->hide = GTK_TOGGLE_BUTTON(widget)->active;
+	cd->hide = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 	set_chartdata_split_heights(cd->chart);
 	gkrellm_rescale_chart(cd->chart);
 	}
@@ -2396,7 +2396,7 @@ static void
 cb_split_mode(GtkWidget *widget, GkrellmChartdata *cd)
 	{
 	_GK.config_modified = TRUE;
-	cd->split_chart = GTK_TOGGLE_BUTTON(widget)->active;
+	cd->split_chart = gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(widget));
 	gtk_widget_set_sensitive(cd->split_fraction_spin_button, cd->split_chart);
 	set_chartdata_split_heights(cd->chart);
 	gkrellm_rescale_chart(cd->chart);
@@ -2418,92 +2418,114 @@ cb_split_fraction(GtkWidget *adjustment, GkrellmChartdata *cd)
 /* =================================================================== */
 
 static void
-cb_auto_res_control(GkrellmChart *cp, guint option, GtkWidget* widget)
-    {
-    GkrellmChartconfig *cf;
-	gint			grid_res;
-	gboolean		active;
+cb_seq_control(GtkRadioAction *action, GtkRadioAction *current, GkrellmChart *cp )
+{
+    GkrellmChartconfig *cf = cp->config;
 
-	cf = cp->config;
-    switch (option)
-        {
-        case 0:
-			cp->maxval_auto_base = 0;
-			cp->maxval_peak = 0;
-			break;
-        case 1:
-            active = GTK_CHECK_MENU_ITEM(widget)->active;
-			cf->auto_resolution_stick = active;
-			cp->maxval_auto_base = 0;
-            break;
-        case 2:
-            active = GTK_CHECK_MENU_ITEM(widget)->active;
-			if (cf->sequence_125 && active)
-				return;
-			cf->sequence_125 = active;
-			break;
-        case 3:
-            active = GTK_CHECK_MENU_ITEM(widget)->active;
-			if (!cf->sequence_125 && active)
-				return;
-			cf->sequence_125 = !active;
+    if (cf->sequence_125 == gtk_radio_action_get_current_value(action))
+        return;
+    cf->sequence_125 = gtk_radio_action_get_current_value(action);
 
-			grid_res = gkrellm_125_sequence(cf->grid_resolution,
-						cf->sequence_125, cf->low, cf->high, TRUE, FALSE);
-			cf->grid_resolution = grid_res;
-			set_grid_resolution_spin_button(cp, grid_res);
-            break;
-        }
-	gkrellm_refresh_chart(cp);
-    }
+    cf->grid_resolution = gkrellm_125_sequence(cf->grid_resolution,
+                                               cf->sequence_125, cf->low, cf->high, TRUE, FALSE);
+    set_grid_resolution_spin_button(cp, cf->grid_resolution);
+}
 
+static void
+cb_auto_stick_control(GtkToggleAction *action, GkrellmChart *cp )
+{
+    GkrellmChartconfig *cf = cp->config;
 
-static GtkItemFactoryEntry	auto_res_control_items[] =
-    {
-{N_("/Control"),	NULL,	NULL,				 0,	"<LastBranch>" },
-{N_("/Control/-"),	NULL,	NULL,				 0,	"<Separator>"},
-{N_("/Control/Auto mode recalibrate"),
-					NULL,	cb_auto_res_control, 0, "<Item>"},
-{N_("/Control/Auto mode sticks at peak value"),
-					NULL,	cb_auto_res_control, 1,	"<ToggleItem>"},
-{N_("/Control/-"),	NULL,    NULL,				 0,	"<Separator>"},
-{N_("/Control/Sequence.../1 2 5"),
-					NULL,	cb_auto_res_control, 2,	"<RadioItem>"},
-{N_("/Control/Sequence.../1 1.5 2 3 5 7"),
-					NULL,	cb_auto_res_control, 3,
-					N_("/Control/Sequence.../1 2 5")},
-{N_("/Control/-"),	 NULL,	NULL,				 0,	"<Separator>"},
-    };
+    cf->auto_resolution_stick = gtk_toggle_action_get_active(GTK_TOGGLE_ACTION(action));
+    cp->maxval_auto_base = 0;
+    gkrellm_refresh_chart(cp);
+}
+
+static void
+cb_auto_res_control(GtkAction *action, GkrellmChart *cp )
+{
+    cp->maxval_auto_base = 0;
+    cp->maxval_peak = 0;
+    gkrellm_refresh_chart(cp);
+}
+
+static const char *auto_res_control_items = "\
+<ui>\
+  <menubar>\
+  <menu name=\"Control\" action=\"ControlAction\">\
+    <separator/>\
+    <menuitem name=\"AutoModeRecalibrate\" action=\"AutoModeRecalibrateAction\"/>\
+    <menuitem name=\"AutoModeStickPeak\" action=\"AutoModeStickPeakAction\"/>\
+    <menu name=\"SequenceMenu\" action=\"SequenceMenuAction\">\
+      <menuitem name=\"Seq125\" action=\"Seq125Action\"/>\
+      <menuitem name=\"Seq1357\" action=\"Seq1357Action\"/>\
+    </menu>\
+    <separator/>\
+  </menu>\
+  </menubar>\
+</ui>\
+";
+
+static GtkActionEntry auto_res_control_entries[] = 
+{
+    { "ControlAction", NULL, N_("Control"),
+      NULL, NULL, G_CALLBACK(NULL) },
+    { "SequenceMenuAction", NULL, N_("Sequence..."),
+      NULL, NULL, G_CALLBACK(NULL) },
+    { "AutoModeRecalibrateAction", NULL, N_("Auto mode recalibrate"),
+      NULL, NULL, G_CALLBACK(cb_auto_res_control) },
+};
+static guint n_auto_res_control_entries = G_N_ELEMENTS (auto_res_control_entries);
+
+static GtkToggleActionEntry auto_res_control_toggle_entries[] = 
+{
+    { "AutoModeStickPeakAction", NULL, N_("Auto mode sticks at peak value"),
+      NULL, NULL, G_CALLBACK(cb_auto_stick_control), FALSE },
+};
+static guint n_auto_res_control_toggle_entries = G_N_ELEMENTS (auto_res_control_toggle_entries);
+
+static GtkRadioActionEntry auto_res_control_radio_entries[] = 
+{
+    { "Seq125Action", NULL, N_("1 2 5"),
+      NULL, NULL, 1 },
+    { "Seq1357Action", NULL, N_("1 1.5 2 3 5 7"),
+      NULL, NULL, 0 },
+};
+static guint n_auto_res_control_radio_entries = G_N_ELEMENTS (auto_res_control_radio_entries);
 
 static void
 auto_resolution_control_menubar(GtkWidget **menubar, GkrellmChart *cp)
 	{
-	GtkItemFactory	*item_factory;
+        GtkUIManager *ui_manager;
+        GtkActionGroup *action_group;
 	GkrellmChartconfig		*cf = cp->config;
-	gint			i, n;
-	static gboolean	translated;
+        GError *error;
 
-	n = sizeof(auto_res_control_items) / sizeof(GtkItemFactoryEntry);
-	item_factory = gtk_item_factory_new(GTK_TYPE_MENU_BAR, "<main>", NULL);
-	if (!translated)
-		{
-		for(i = 0; i < n; i++)
-			auto_res_control_items[i].path = _(auto_res_control_items[i].path);
-		auto_res_control_items[6].item_type =
-				_(auto_res_control_items[6].item_type);
-		translated = TRUE;
-		}
-	gtk_item_factory_create_items(item_factory, n, auto_res_control_items, cp);
-	cf->auto_resolution_item_factory = item_factory;
+        action_group = gtk_action_group_new ("ControlActions");
+        gtk_action_group_add_actions (action_group, auto_res_control_entries,
+                                      n_auto_res_control_entries, cp);
+        gtk_action_group_add_toggle_actions (action_group, auto_res_control_toggle_entries,
+                                             n_auto_res_control_toggle_entries, cp);
+        gtk_action_group_add_radio_actions (action_group, auto_res_control_radio_entries,
+                                            n_auto_res_control_radio_entries,
+                                            !!cf->sequence_125, G_CALLBACK(cb_seq_control),
+                                            cp);
+        ui_manager = gtk_ui_manager_new ();
+        error = NULL;
+        gtk_ui_manager_add_ui_from_string (ui_manager, auto_res_control_items,
+                                           strlen(auto_res_control_items), &error);
+        if (error)
+        {
+            g_message ("building menus failed: %s", error->message);
+            g_error_free (error);
+            return;
+        }
+        gtk_ui_manager_insert_action_group (ui_manager, action_group, 0);
+	cf->auto_resolution_ui_manager = ui_manager;
 	set_resolution_menubar_items_sensitivity(cf);
 
-	GTK_CHECK_MENU_ITEM(gtk_item_factory_get_widget(item_factory,
-		_("/Control/Sequence.../1 2 5")))->active = cf->sequence_125;
-	GTK_CHECK_MENU_ITEM(gtk_item_factory_get_widget(item_factory,
-		_("/Control/Sequence.../1 1.5 2 3 5 7")))->active = !cf->sequence_125;
-
 	if (menubar)
-		*menubar = gtk_item_factory_get_widget(item_factory, "<main>");
+		*menubar = gtk_ui_manager_get_widget(ui_manager, "/menubar");
 	}
 
 void
@@ -2525,7 +2547,7 @@ gkrellm_chartconfig_window_create(GkrellmChart *cp)
 		return;
 		}
 	cp->config_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-	g_signal_connect(G_OBJECT(cp->config_window), "delete_event",
+	g_signal_connect(G_OBJECT(cp->config_window), "delete-event",
 			G_CALLBACK(chart_config_window_delete_event), cp);
 
 	p = cp->panel;
@@ -2590,7 +2612,7 @@ gkrellm_chartconfig_window_create(GkrellmChart *cp)
 		}
 
 	cf->auto_resolution_control_menubar = NULL;
-	cf->auto_resolution_item_factory = NULL;
+	cf->auto_resolution_ui_manager = NULL;
 	cf->grid_resolution_spin_button = NULL;
 	cf->fixed_grids_spin_button = NULL;
 
@@ -2653,7 +2675,7 @@ gkrellm_chartconfig_window_create(GkrellmChart *cp)
 	gtk_box_pack_start(GTK_BOX(main_vbox), hbox, FALSE, FALSE, 0);
 
 	button = gtk_button_new_from_stock(GTK_STOCK_OK);
-	GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+	gtk_widget_set_can_default(button, 1);
 	g_signal_connect(G_OBJECT(button), "clicked",
 			G_CALLBACK(chart_config_window_close), cp);
     gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 15);
@@ -2733,29 +2755,3 @@ gkrellm_load_chartconfig(GkrellmChartconfig **config, gchar *string,
 			break;
 		}
 	}
-
-void
-debug_dump_chart_list()
-	{
-	GList			*list, *cdlist;
-	GkrellmChart	*cp;
-	GkrellmPanel	*p;
-	GkrellmChartdata *cd;
-
-	g_debug("\n");
-	for (list = gkrellm_get_chart_list(); list; list = list->next)
-		{
-		cp = (GkrellmChart *) list->data;
-		p = cp->panel;
-		if (p && p->label && p->label->string)
-			g_debug("%s [%d]: ", p->label->string, cp->style_id);
-		else
-			g_debug("(null) [%d]: ", cp->style_id);
-		for (cdlist = cp->cd_list; cdlist; cdlist = cdlist->next)
-			{
-			cd = (GkrellmChartdata *) cdlist->data;
-			g_debug("%s %p->data ", cd->label, cd->data);
-			}
-		g_debug("\n");
-		}
-	}
