@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2010 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -119,6 +119,8 @@ gkrellm_panel_configure(GkrellmPanel *p, gchar *string, GkrellmStyle *style)
 	GkrellmDecal	*d;
 	GkrellmLabel	*lbl;
 	GkrellmTextstyle *ts = NULL;
+	PangoLayoutIter	*iter;
+	PangoRectangle	ink, logical;
 	gint			y, h_panel, h, baseline;
 	gint			top_margin = 0, bottom_margin = 0;
 
@@ -132,6 +134,11 @@ gkrellm_panel_configure(GkrellmPanel *p, gchar *string, GkrellmStyle *style)
 
 	ts = p->textstyle;
 
+	if (p->label_layout)
+		{
+		g_object_unref(p->label_layout);
+		p->label_layout = NULL;
+		}
 	if (string)
 		{
 		if (g_utf8_validate(string, -1, NULL))
@@ -143,8 +150,28 @@ gkrellm_panel_configure(GkrellmPanel *p, gchar *string, GkrellmStyle *style)
 		gkrellm_dup_string(&lbl->string, string);
 
 	if (lbl->string && ts && lbl->position >= 0)
-		gkrellm_text_extents(ts->font, string, strlen(string),
-				&lbl->width, &lbl->height, &baseline, NULL);
+		{
+		p->label_layout =
+				gtk_widget_create_pango_layout(gkrellm_get_top_window(), NULL);
+		pango_layout_set_font_description(p->label_layout, ts->font);
+		if (pango_parse_markup(lbl->string, -1, 0, NULL, NULL, NULL, NULL))
+			pango_layout_set_markup(p->label_layout,
+						lbl->string, strlen(lbl->string));
+		else
+			pango_layout_set_text(p->label_layout,
+						lbl->string, strlen(lbl->string));
+		iter = pango_layout_get_iter(p->label_layout);
+		baseline = pango_layout_iter_get_baseline(iter) / PANGO_SCALE;
+		pango_layout_get_pixel_extents(p->label_layout, &ink, &logical);
+		pango_layout_iter_free(iter);
+
+		lbl->width = logical.width;
+		lbl->height = ink.height;
+		if (ts->effect)
+			lbl->height += 1;
+//		gkrellm_text_extents(ts->font, string, strlen(string),
+//				&lbl->width, &lbl->height, &baseline, NULL);
+		}
 	else
 		{
 		lbl->width = 0;
@@ -219,12 +246,32 @@ draw_panel_label(GkrellmPanel *p, gboolean to_bg)
 	gchar				*s;
 	gint				xdst;
 
-	if (   lbl && ts
+	if (   p->label_layout && lbl && ts
 		&& ((s = lbl->string) != NULL)
 		&& lbl->position >= 0
 	   )
 		{
 		m = gkrellm_get_style_margins(p->style);
+		xdst = gkrellm_label_x_position(lbl->position, p->w,
+								lbl->width, m->left);
+		lbl->x_panel = xdst;
+		if (ts->effect)
+			{
+			gdk_draw_layout_with_colors(p->pixmap, _GK.text_GC,
+					xdst + 1, lbl->y_panel + 1, p->label_layout,
+					&ts->shadow_color, NULL);
+			if (to_bg)
+				gdk_draw_layout_with_colors(p->bg_pixmap, _GK.text_GC,
+						xdst + 1, lbl->y_panel + 1, p->label_layout,
+						&ts->shadow_color, NULL);
+			}
+		gdk_gc_set_foreground(_GK.text_GC, &ts->color);
+		gdk_draw_layout(p->pixmap, _GK.text_GC, xdst,
+						lbl->y_panel, p->label_layout);
+		if (to_bg)
+			gdk_draw_layout(p->bg_pixmap, _GK.text_GC, xdst,
+							lbl->y_panel, p->label_layout);
+#if 0
 		lbl->width = gkrellm_gdk_string_width(ts->font, s) + ts->effect;
 		xdst = gkrellm_label_x_position(lbl->position, p->w,
 					lbl->width, m->left);
@@ -232,6 +279,7 @@ draw_panel_label(GkrellmPanel *p, gboolean to_bg)
 		gkrellm_draw_string(p->pixmap, ts, xdst, lbl->y_panel, s);
 		if (to_bg)
 			gkrellm_draw_string(p->bg_pixmap, ts, xdst, lbl->y_panel, s);
+#endif
 		}
 	}
 
@@ -249,9 +297,9 @@ draw_panel(GkrellmPanel *p, gint to_screen)
 	gdk_draw_drawable(p->bg_text_layer_pixmap, _GK.draw1_GC, p->bg_pixmap,
 					0, 0, 0, 0, p->w, p->h);
 
-	if (p->drawing_area->window && to_screen)
+	if (gtk_widget_get_window(p->drawing_area) && to_screen)
 		{
-		gdk_draw_drawable(p->drawing_area->window, _GK.draw1_GC, p->pixmap,
+		gdk_draw_drawable(gtk_widget_get_window(p->drawing_area), _GK.draw1_GC, p->pixmap,
 					0, 0, 0, 0, p->w, p->h);
 		gkrellm_draw_panel_layers_force(p);
 		}
@@ -280,8 +328,10 @@ gkrellm_panel_destroy(GkrellmPanel *p)
 	gkrellm_destroy_krell_list(p);
 	gkrellm_destroy_decal_list(p);	/* Also destroys buttons */
 	if (p->button_list || p->button_signals_connected)
-		fprintf(stderr, "gkrellm_destroy_panel: button_list=%p connected=%d\n",
-				p->button_list, p->button_signals_connected);
+		{
+		g_warning("gkrellm_destroy_panel: button_list=%p connected=%d\n",
+				(void*)p->button_list, p->button_signals_connected);
+		}
 	if (p->label)
 		{
 		if (p->label->string)
@@ -290,6 +340,9 @@ gkrellm_panel_destroy(GkrellmPanel *p)
 		}
 	if (p->layout)
 		g_object_unref(G_OBJECT(p->layout));
+	if (p->label_layout)
+		g_object_unref(G_OBJECT(p->label_layout));
+
 	if (p->textstyle && p->textstyle->internal)
 		g_free(p->textstyle);
 	if (p->pixmap)
@@ -333,7 +386,7 @@ gkrellm_panel_keep_lists(GkrellmPanel *p, gboolean keep)
 static gboolean
 cb_panel_map_event(GtkWidget *widget, GdkEvent *event, GkrellmPanel *p)
 	{
-	gdk_window_get_position(p->drawing_area->window, NULL, &p->y_mapped);
+	gdk_window_get_position(gtk_widget_get_window(p->drawing_area), NULL, &p->y_mapped);
 	if (_GK.frame_left_panel_overlap > 0 || _GK.frame_right_panel_overlap > 0)
 		_GK.need_frame_packing = TRUE;
 	return FALSE;
@@ -343,7 +396,7 @@ cb_panel_map_event(GtkWidget *widget, GdkEvent *event, GkrellmPanel *p)
 static gboolean
 cb_panel_size_allocate(GtkWidget *widget, GtkAllocation *size, GkrellmPanel *p)
 	{
-	gdk_window_get_position(p->drawing_area->window, NULL, &p->y_mapped);
+	gdk_window_get_position(gtk_widget_get_window(p->drawing_area), NULL, &p->y_mapped);
 	if (_GK.frame_left_panel_overlap > 0 || _GK.frame_right_panel_overlap > 0)
 		_GK.need_frame_packing = TRUE;
 	return FALSE;
@@ -399,7 +452,7 @@ gkrellm_panel_create(GtkWidget *vbox, GkrellmMonitor *mon, GkrellmPanel *p)
 		gtk_widget_realize(p->drawing_area);
 		panel_list = g_list_append(panel_list, p);
 		p->y_mapped = -1;
-		g_signal_connect(G_OBJECT (p->drawing_area), "size_allocate",
+		g_signal_connect(G_OBJECT (p->drawing_area), "size-allocate",
 					G_CALLBACK(cb_panel_size_allocate), p);
 		}
 	gtk_widget_set_size_request(p->drawing_area, p->w, p->h);
@@ -430,13 +483,13 @@ gkrellm_panel_create(GtkWidget *vbox, GkrellmMonitor *mon, GkrellmPanel *p)
 
 	if (p->bg_text_layer_pixmap)
 		g_object_unref(G_OBJECT(p->bg_text_layer_pixmap));
-	p->bg_text_layer_pixmap = gdk_pixmap_new(top_win->window, p->w, p->h, -1);
+	p->bg_text_layer_pixmap = gdk_pixmap_new(gtk_widget_get_window(top_win), p->w, p->h, -1);
 	if (p->bg_pixmap)
 		g_object_unref(G_OBJECT(p->bg_pixmap));
-	p->bg_pixmap = gdk_pixmap_new(top_win->window, p->w, p->h, -1);
+	p->bg_pixmap = gdk_pixmap_new(gtk_widget_get_window(top_win), p->w, p->h, -1);
 	if (p->pixmap)
 		g_object_unref(G_OBJECT(p->pixmap));
-	p->pixmap = gdk_pixmap_new(top_win->window, p->w, p->h, -1);
+	p->pixmap = gdk_pixmap_new(gtk_widget_get_window(top_win), p->w, p->h, -1);
 
 	if (p->shown)
 		{
@@ -519,9 +572,10 @@ gkrellm_panel_cleanup(void)
 			gkrellm_destroy_krell_list(p);
 			gkrellm_destroy_decal_list(p);	/* Also destroys buttons */
 			if (p->krell_list || p->decal_list || p->button_list)
-				fprintf(stderr,
-					"GKrellM: gkrellm_panel_cleanup krell=%p decal=%p button=%p\n",
-						p->krell_list, p->decal_list, p->button_list);
+				{
+				g_warning("gkrellm_panel_cleanup krell=%p decal=%p button=%p\n",
+						(void*)p->krell_list, (void*)p->decal_list, (void*)p->button_list);
+				}
 			}
 		else
 			{
@@ -606,7 +660,7 @@ panel_draw_decal_text_list(GdkPixmap *pixmap, GkrellmDecal *d)
 		y = tx->y_off;
 		if (d->flags & DF_SCROLL_TEXT_DIVERTED)
 			{
-			if (d->flags & DF_SCROLL_TEXT_CENTER)
+			if (d->flags & DF_TEXT_CENTER)
 				pango_layout_set_alignment(layout, PANGO_ALIGN_CENTER);
 			if (d->flags & DF_SCROLL_TEXT_H_LOOP)
 				{
@@ -642,6 +696,8 @@ panel_draw_decal_text_list(GdkPixmap *pixmap, GkrellmDecal *d)
 			}
 		else
 			{
+			if (d->flags & DF_TEXT_CENTER)
+				pango_layout_set_alignment(layout, PANGO_ALIGN_CENTER);
 			if (d->flags & DF_TEXT_USE_MARKUP)
 				pango_layout_set_markup(layout, tx->text, strlen(tx->text));
 			else
@@ -894,8 +950,8 @@ gkrellm_draw_panel_layers(GkrellmPanel *p)
 		if (do_top_layer_decals)
 			push_decal_pixmaps(p, TRUE);
 
-		if (p->drawing_area->window)
-			gdk_draw_drawable(p->drawing_area->window, _GK.draw1_GC, p->pixmap,
+		if (gtk_widget_get_window(p->drawing_area))
+			gdk_draw_drawable(gtk_widget_get_window(p->drawing_area), _GK.draw1_GC, p->pixmap,
 						0, 0,   0, 0,   p->w, p->h);
 		}
 	p->modified = FALSE;
