@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2010 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -74,7 +74,7 @@ gkrellm_clone_pixmap(GdkPixmap **dest, GdkPixmap **src)
 			gkrellm_free_pixmap(dest);
 		}
 	if (!*dest)
-		*dest = gdk_pixmap_new(gkrellm_get_top_window()->window,
+		*dest = gdk_pixmap_new(gtk_widget_get_window(gkrellm_get_top_window()),
 					w_src, h_src, -1);
 	gdk_draw_drawable(*dest, _GK.draw1_GC, *src, 0, 0, 0, 0, w_src, h_src);
 	return TRUE;	
@@ -100,7 +100,7 @@ gkrellm_clone_bitmap(GdkBitmap **dest, GdkBitmap **src)
 			gkrellm_free_bitmap(dest);
 		}
 	if (!*dest)
-		*dest = gdk_pixmap_new(gkrellm_get_top_window()->window,
+		*dest = gdk_pixmap_new(gtk_widget_get_window(gkrellm_get_top_window()),
 					w_src, h_src, 1);
 	gdk_draw_drawable(*dest, _GK.bit1_GC, *src, 0, 0, 0, 0, w_src, h_src);
 	return TRUE;	
@@ -123,7 +123,7 @@ gboolean
 gkrellm_scale_pixbuf_to_pixmap(GdkPixbuf *src_pixbuf, GdkPixmap **pixmap,
 			GdkBitmap **mask, gint w_dst, gint h_dst)
 	{
-	GdkWindow		*window = gkrellm_get_top_window()->window;
+	GdkWindow		*window = gtk_widget_get_window(gkrellm_get_top_window());
 	GdkPixbuf		*dst_pixbuf;
 	gint			w_src, h_src;
 	gboolean		has_alpha;
@@ -331,7 +331,7 @@ gboolean
 gkrellm_scale_piximage_to_pixmap(GkrellmPiximage *piximage, GdkPixmap **pixmap,
 			GdkBitmap **mask, gint w_dst, gint h_dst)
 	{
-	GdkWindow		*window = gkrellm_get_top_window()->window;
+	GdkWindow		*window = gtk_widget_get_window(gkrellm_get_top_window());
 	GdkPixbuf		*src_pixbuf, *dst_pixbuf;
 	gint			w_src, h_src;
 	gboolean		has_alpha;
@@ -436,7 +436,7 @@ gboolean
 gkrellm_scale_theme_background(GkrellmPiximage *piximage, GdkPixmap **pixmap,
 			GdkBitmap **mask, gint w_dst, gint h_dst)
 	{
-	GdkWindow		*window = gkrellm_get_top_window()->window;
+	GdkWindow		*window = gtk_widget_get_window(gkrellm_get_top_window());
 	GdkPixbuf		*src_pixbuf, *sub_pixbuf, *pixbuf;
 	GdkInterpType	interp_type;
 	GkrellmBorder	bdr;
@@ -672,8 +672,23 @@ gkrellm_piximage_new_from_inline(const guint8 *data, gboolean copy_pixels)
 	{
 	GkrellmPiximage	*piximage;
 	GdkPixbuf		*pixbuf;
+	guint			width, height, stride;
+	guint8			*d = (guint8 *) data;
+	gpointer		pixels;
+
+
+//	pixbuf = gdk_pixbuf_new_from_inline(-1, data, copy_pixels, NULL);
+	stride = big_endian_uint(d + 12);
+	width  = big_endian_uint(d + 16);
+	height = big_endian_uint(d + 20);
+
+	pixels = g_memdup2((gconstpointer)(d + 24), height * stride);
+
+	pixbuf = gdk_pixbuf_new_from_data(pixels,
+				GDK_COLORSPACE_RGB, TRUE, 8, width, height, stride,
+				(GdkPixbufDestroyNotify) g_free, pixels);
+
 
-	pixbuf = gdk_pixbuf_new_from_inline(-1, data, copy_pixels, NULL);
  	if (!pixbuf)
 		return NULL;
 	piximage = g_new0(GkrellmPiximage, 1);
