@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2010 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -807,7 +807,7 @@ void
 gkrellm_place_plugin(GList **monitor_list, GkrellmMonitor *plugin)
 	{
 	GkrellmMonitor	*mon;
-	GList			*list, *plist, *waste;
+	GList			*list, *plist;
 	gint			n, gravity, after_flag;
 	gchar			buf[120];
 
@@ -857,10 +857,9 @@ gkrellm_place_plugin(GList **monitor_list, GkrellmMonitor *plugin)
 						}
 					list = plist;
 					}
-				if (list == *monitor_list)
-					*monitor_list = g_list_prepend(list, plugin);
-				else
-					waste = g_list_prepend(list, plugin);
+				if ((n = g_list_position(*monitor_list, list)) < 0)
+					n = 0;
+				*monitor_list = g_list_insert(*monitor_list, plugin, n);
 				}
 			return;
 			}
@@ -882,7 +881,7 @@ install_plugin(gchar *plugin_name)
 	GList					*list;
 	GModule					*module;
 	GkrellmMonitor			*m, *mm;
-	GkrellmMonitor			*(*init_plugin)();
+	GkrellmMonitor			*(*init_plugin)(void);
 	gchar					buf[256];
 	static GkrellmMonitor	mon_tmp;
 
@@ -1265,23 +1264,14 @@ gkrellm_plugins_load(void)
 	g_free(path);
 
 #if defined(WIN32)
-	path = NULL;
-#if GLIB_CHECK_VERSION(2,16,0)
 	gchar *install_path;
 	install_path = g_win32_get_package_installation_directory_of_module(NULL);
 	if (install_path != NULL)
 		{
 		path = g_build_filename(install_path, "lib", "gkrellm2", "plugins", NULL);
-		g_free(install_path);
-		}
-#else
-	// deprecated since glib 2.16.0
-	path = g_win32_get_package_installation_subdirectory(NULL, NULL, "lib/gkrellm2/plugins");
-#endif
-	if (path)
-		{
 		scan_for_plugins(path);
 		g_free(path);
+		g_free(install_path);
 		}
 #endif
 
@@ -1325,7 +1315,7 @@ shuffle_test(void)
 #endif
 
 static void
-replace_plugins()
+replace_plugins(void)
 	{
 	GList			*new_monitor_list, *list;
 	GkrellmMonitor	*mon;
@@ -1337,7 +1327,7 @@ replace_plugins()
 		mon = (GkrellmMonitor *) list->data;
 		if (mon->privat->main_vbox && mon != gkrellm_mon_host())
 			{
-			gtk_widget_ref(mon->privat->main_vbox);
+                            g_object_ref(G_OBJECT(mon->privat->main_vbox));
 			gtk_container_remove(GTK_CONTAINER(gkrellm_monitor_vbox()),
 					mon->privat->main_vbox);
 			}
@@ -1359,7 +1349,7 @@ replace_plugins()
 			{
 			gtk_box_pack_start(GTK_BOX(gkrellm_monitor_vbox()),
 					mon->privat->main_vbox, FALSE, FALSE, 0);
-			gtk_widget_unref(mon->privat->main_vbox);
+			g_object_unref(G_OBJECT(mon->privat->main_vbox));
 			}
 		}
 	}
@@ -1379,7 +1369,7 @@ apply_place(void)
 	if (!place_plugin || setting_place_buttons)
 		return;
 	for (i = 0; i < N_BUILTIN_MONITORS; ++i)
-		if (GTK_TOGGLE_BUTTON(builtin_button[i])->active)
+		if (gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(builtin_button[i])))
 			break;
 	for (list = gkrellm_monitor_list; list; list = list->next)
 		{
@@ -1388,7 +1378,7 @@ apply_place(void)
 			continue;
 		place_plugin->privat->insert_before_id = mon->id;
 		place_plugin->privat->insert_after =
-				GTK_TOGGLE_BUTTON(after_button)->active;
+				gtk_toggle_button_get_active(GTK_TOGGLE_BUTTON(after_button));
 		if (place_plugin->privat->insert_after)
 			place_plugin->privat->gravity = 0;
 		else
@@ -1483,7 +1473,7 @@ place_button_sensitivity(GkrellmMonitor *plugin, gboolean state)
 static gboolean
 cb_place(GtkToggleButton *button, gpointer data)
 	{
-	if (!button->active)
+	if (!gtk_toggle_button_get_active(button))
 		return FALSE;
 	apply_place();
 	return TRUE;
@@ -1512,7 +1502,6 @@ cb_place_button(GtkWidget *widget, gpointer data)
 	GSList			*group;
 	GList			*list;
 	GkrellmMonitor	*mon;
-	GkrellmMonprivate *mp;
 	gint			i;
 
 	if (gkrellm_demo_mode())
@@ -1520,7 +1509,7 @@ cb_place_button(GtkWidget *widget, gpointer data)
 	if (!place_plugin_window)
 		{
 		place_plugin_window = gtk_window_new(GTK_WINDOW_TOPLEVEL);
-		g_signal_connect(G_OBJECT(place_plugin_window), "delete_event",
+		g_signal_connect(G_OBJECT(place_plugin_window), "delete-event",
 				G_CALLBACK(place_plugin_window_delete_event), NULL);
 		gtk_window_set_title(GTK_WINDOW(place_plugin_window),
 				_("GKrellM Place Plugin"));
@@ -1540,7 +1529,6 @@ cb_place_button(GtkWidget *widget, gpointer data)
 		for (i = 0, list = gkrellm_monitor_list; list; list = list->next)
 			{
 			mon = (GkrellmMonitor *) list->data;
-			mp  = mon->privat;
 			mon->privat->button_id = -1;
 			if (MONITOR_ID(mon) != MON_PLUGIN)
 				{
@@ -1598,7 +1586,7 @@ cb_place_button(GtkWidget *widget, gpointer data)
 		gtk_box_pack_end(GTK_BOX(vbox1), hbox, FALSE, FALSE, 0);
 
 		button = gtk_button_new_from_stock(GTK_STOCK_OK);
-		GTK_WIDGET_SET_FLAGS(button, GTK_CAN_DEFAULT);
+		gtk_widget_set_can_default(button, 1);
 		g_signal_connect(G_OBJECT(button), "clicked",
 				G_CALLBACK(cb_close_place), NULL);
 		gtk_box_pack_start(GTK_BOX(hbox), button, TRUE, TRUE, 0);
@@ -1740,7 +1728,6 @@ gkrellm_plugins_config_create(GtkWidget *tab_vbox)
 	model = create_model();
 	treeview = GTK_TREE_VIEW(gtk_tree_view_new_with_model(model));
 	g_object_unref(G_OBJECT(model));
-	gtk_tree_view_set_rules_hint(treeview, TRUE);
 
 	renderer = gtk_cell_renderer_toggle_new();
 	gtk_tree_view_insert_column_with_attributes(treeview, -1, _("Enable"),
@@ -1773,7 +1760,7 @@ gkrellm_plugins_config_create(GtkWidget *tab_vbox)
 
 	place_button = gtk_button_new_with_label(_("Place"));
 	gtk_box_pack_start(GTK_BOX(hbox), place_button, TRUE, TRUE, 0);
-	g_signal_connect(G_OBJECT(GTK_BUTTON(place_button)), "clicked",
+	g_signal_connect(G_OBJECT(place_button), "clicked",
 			G_CALLBACK(cb_place_button), NULL);
 	gtk_widget_set_sensitive(place_button, FALSE);
 
