@@ -1,8 +1,8 @@
 /* GKrellM
-|  Copyright (C) 1999-2010 Bill Wilson
+|  Copyright (C) 1999-2021 Bill Wilson
 |
 |  Author:  Bill Wilson    billw@gkrellm.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -89,7 +89,7 @@
 #endif
 
 #if !defined(SENSORS_COMMON) && !defined(WIN32)
-static gboolean (*mbmon_check_func)();
+static gboolean (*mbmon_check_func)(gboolean);
 #endif
 
 gchar *
