@@ -1,10 +1,10 @@
 /* GKrellM
-|  Copyright (C) 1999-2010 Bill Wilson
-|                2007-2010 Stefan Gehn
+|  Copyright (C) 1999-2021 Bill Wilson
+|                2007-2024 Stefan Gehn
 |
 |  Authors:  Bill Wilson    billw@gkrellm.net
 |            Stefan Gehn    stefan+gkrellm@srcbox.net
-|  Latest versions might be found at:  http://gkrellm.net
+|  Latest versions might be found at:  https://gkrellm.srcbox.net
 |
 |
 |  GKrellM is free software: you can redistribute it and/or modify it
@@ -455,5 +455,5 @@ void win32_init_callbacks(void)
 
     gkrellm_callbacks.gkrellm_debugv = gkrellm_debugv;
 
-} // win32_init_callbacks()
+}
 
